@@ -54,6 +54,7 @@ use App::Dochazka::REST::Model::Employee qw(
     noof_employees_by_priv 
 );
 use App::Dochazka::REST::Model::Interval qw(
+    delete_intervals_by_eid_and_tsrange
     fetch_intervals_by_eid_and_tsrange
 );
 use App::Dochazka::REST::Model::Lock qw(
@@ -1638,19 +1639,22 @@ sub handler_history_delete_shid {
 =head2 Interval handlers
 
 
-=head3 handler_get_interval_eid
+=head3 handler_interval_eid
 
-Handler for 'GET interval/eid/:eid/:tsrange'
+Handler for 
+
+    GET interval/eid/:eid/:tsrange
+    DELETE interval/eid/:eid/:tsrange
 
 #FIXME: implement a configurable limit on the tsrange
 
 =cut
 
-sub handler_get_interval_eid {
+sub handler_interval_eid {
     my ( $self, $pass ) = @_;
-    $log->debug( "Entering " . __PACKAGE__ . "::handler_get_interval_eid " ); 
+    $log->debug( "Entering " . __PACKAGE__ . "::handler_interval_eid " ); 
 
-    return $self->_handler_get_intlock( 'Interval', 'eid', $pass );
+    return $self->_handler_intlock( 'Interval', 'eid', $pass );
 }
 
 
@@ -1666,23 +1670,26 @@ sub handler_get_lock_eid {
     my ( $self, $pass ) = @_;
     $log->debug( "Entering " . __PACKAGE__ . "::handler_get_lock_eid " ); 
 
-    return $self->_handler_get_intlock( 'Lock', 'eid', $pass );
+    return $self->_handler_intlock( 'Lock', 'eid', $pass );
 }
 
 
-=head3 handler_get_interval_nick
+=head3 handler_interval_nick
 
-Handler for 'GET interval/nick/:nick/:tsrange'
+Handler for 
+
+    GET interval/nick/:nick/:tsrange
+    DELETE interval/nick/:nick/:tsrange
 
 #FIXME: implement a configurable limit on the tsrange
 
 =cut
 
-sub handler_get_interval_nick {
+sub handler_interval_nick {
     my ( $self, $pass ) = @_;
-    $log->debug( "Entering " . __PACKAGE__ . "::handler_get_interval_nick " ); 
+    $log->debug( "Entering " . __PACKAGE__ . "::handler_interval_nick " ); 
 
-    return $self->_handler_get_intlock( 'Interval', 'nick', $pass );
+    return $self->_handler_intlock( 'Interval', 'nick', $pass );
 }
 
 
@@ -1698,23 +1705,26 @@ sub handler_get_lock_nick {
     my ( $self, $pass ) = @_;
     $log->debug( "Entering " . __PACKAGE__ . "::handler_get_lock_nick " ); 
 
-    return $self->_handler_get_intlock( 'Lock', 'nick', $pass );
+    return $self->_handler_intlock( 'Lock', 'nick', $pass );
 }
 
 
-=head3 handler_get_interval_self
+=head3 handler_interval_self
 
-Handler for 'GET interval/self/:tsrange'
+Handler for 
+
+    GET interval/self/:tsrange
+    DELETE interval/self/:tsrange
 
 #FIXME: implement a configurable limit on the tsrange
 
 =cut
 
-sub handler_get_interval_self {
+sub handler_interval_self {
     my ( $self, $pass ) = @_;
-    $log->debug( "Entering " . __PACKAGE__ . "::handler_get_interval_self " ); 
+    $log->debug( "Entering " . __PACKAGE__ . "::handler_interval_self " ); 
 
-    return $self->_handler_get_intlock( 'Interval', 'self', $pass );
+    return $self->_handler_intlock( 'Interval', 'self', $pass );
 }
 
 
@@ -1730,11 +1740,11 @@ sub handler_get_lock_self {
     my ( $self, $pass ) = @_;
     $log->debug( "Entering " . __PACKAGE__ . "::handler_get_lock_self " ); 
 
-    return $self->_handler_get_intlock( 'Lock', 'self', $pass );
+    return $self->_handler_intlock( 'Lock', 'self', $pass );
 }
 
 
-sub _handler_get_intlock {
+sub _handler_intlock {
     my ( $self, $intlock, $key, $pass ) = @_;
 
     my $context = $self->context;
@@ -1771,16 +1781,19 @@ sub _handler_get_intlock {
             $emp->eid,
             $tsr,
         );
-        if ( $intlock eq 'Interval' ) {
+        my $method = $self->context->{'method'};
+        if ( $method eq 'GET' and $intlock eq 'Interval' ) {
             $status = fetch_intervals_by_eid_and_tsrange( @ARGS );
-        } elsif ( $intlock eq 'Lock' ) {
+        } elsif ( $method eq 'GET' and $intlock eq 'Lock' ) {
             $status = fetch_locks_by_eid_and_tsrange( @ARGS );
+        } elsif ( $method eq 'DELETE' and $intlock eq 'Interval' ) {
+            $status = delete_intervals_by_eid_and_tsrange( @ARGS );
         } else {
             die "AGACHCH!! Horrible, horrible: " . ( $intlock || "undef" );
         }
         if ( $status->level eq 'NOTICE' and $status->code eq 'DISPATCH_NO_RECORDS_FOUND' ) {
             $self->mrest_declare_status( explanation => 'DISPATCH_NOTHING_IN_TSRANGE',
-                args => [ 'attendance intervals' ] 
+                args => [ 'attendance intervals', $tsr ] 
             );
             return 0;
         }
